@@ -42,6 +42,18 @@ function(mdf,fixform = Ymat ~ 1,components=c("VarE(I)","VarG(Ia)"),specific.comp
       }
     }
   }
+# check nonspecific and specific components dont clash
+  if(!is.null(specific.components)){
+    for(i in 1:length(specific.components)) {
+      if(any(!is.na(match(specific.components[[i]],components)))){
+        cat("Components = ")
+        print(components)
+        cat(" clashes with specific component = ")
+        print(specific.components[i])
+        stop("A component can not be both nonspecific and class specific\n")
+      }
+    }
+  }
 #
   if(is.null(mdf$rel)) {
     df <- mdf
@@ -448,10 +460,9 @@ function(mdf,fixform = Ymat ~ 1,components=c("VarE(I)","VarG(Ia)"),specific.comp
 # sesiga <- ielist$sesigaie
 # vsiga <- ielist$vsigaie
 
-# map siga int vc list of phencovclasses
+# map siga into vc list of phencovclasses
   vclist <- sigatovc(ielist$siga,ielist$vsiga,ielist$sesiga,am,nsf)
 
-
     # genetic parameters
     ols.specific.genpar.list <- vector("list",length=length(vclist$phencovclasses))
     for ( ic in 1:length(vclist$phencovclasses)) {
@@ -482,8 +493,8 @@ function(mdf,fixform = Ymat ~ 1,components=c("VarE(I)","VarG(Ia)"),specific.comp
    }
 
 #  GLS iteration of b's
-cat("v = ",am$v,"\n")
-cat("l = ",am$l,"\n")
+# cat("v = ",am$v,"\n")
+# cat("l = ",am$l,"\n")
    gls.list <- gls.iter.b(am, b, siga, dyad.explist, glsopt, dmeopt, ctable, ncomp.pcr, dmekeepfit)
 
      if(gls.list$ok) {
@@ -515,7 +526,7 @@ cat("l = ",am$l,"\n")
 #       sesiga <- ielist$sesigaie
 #       vsiga <- ielist$vsigaie
         
-#  map siga int vc list of phencovclasses
+#  map siga into vc list of phencovclasses
         vclist <- sigatovc(ielist$siga,ielist$vsiga,ielist$sesiga,am,nsf)
 
 #  genetic parameters for each phencovclass
